from rakam_systems_vectorstore import *
from rakam_systems_vectorstore.core import Node, NodeMetadata, VSFile
from rakam_systems_vectorstore.config import (
    VectorStoreConfig,
    EmbeddingConfig,
    DatabaseConfig,
    SearchConfig,
    IndexConfig,
    load_config,
)
from rakam_systems_vectorstore.components.vectorstore.configurable_pg_vector_store import ConfigurablePgVectorStore
from rakam_systems_vectorstore.components.vectorstore.pg_vector_store import PgVectorStore
from rakam_systems_vectorstore.components.vectorstore.faiss_vector_store import FaissStore as FaissVectorStore
from rakam_systems_vectorstore.components.loader.adaptive_loader import AdaptiveLoader, create_adaptive_loader
from rakam_systems_vectorstore.components.embedding_model.configurable_embeddings import ConfigurableEmbeddings, create_embedding_model



"""Rakam Systems — modular AI framework."""

import sys

import rakam_systems_agent as agent
import rakam_systems_cli as cli
import rakam_systems_core as core
import rakam_systems_tools as tools
import rakam_systems_vectorstore as vectorstore

# Register aliases so `from rakam_systems.agent import X` resolves correctly.
sys.modules.update(
    {
        "rakam_systems.agent": agent,
        "rakam_systems.agents": agent,
        "rakam_systems.cli": cli,
        "rakam_systems.core": core,
        "rakam_systems.tools": tools,
        "rakam_systems.vectorstore": vectorstore,
    }
)

__all__ = ["core", "cli", "agent", "vectorstore", "tools"]



from rakam_systems_agent import *
from rakam_systems_agent import (
    BaseAgent,
    LLMGateway,
    LLMRequest,
    LLMResponse,
    OpenAIGateway,
    MistralGateway,
    LLMGatewayFactory,
    get_llm_gateway,
    JSONChatHistory,
    SQLChatHistory,
    PostgresChatHistory,
)



from rakam_systems_core import *
from rakam_systems_core.base import BaseComponent
from rakam_systems_core.config import Settings
from rakam_systems_core.tracking import TrackingManager, TrackingMixin, get_tracking_manager, track_method
